clashroyale
===========

.. image:: https://img.shields.io/pypi/v/clashroyale.svg
   :alt: PyPi


This library is currently an (a)sync wrapper for https://royaleapi.com with
great functionality.

Installation
------------

.. code-block:: python

    pip install clashroyale

Documentation
-------------

Currently we don't have any documentation, read through the source /
examples to get a feel on how to use the wrapper. If you would like to
contribute to documentation, comment on the issue or
create a pull request.

`Current Docs <https://github.com/kyb3r/clashroyale/issues/1>`_


Misc
----

If you have any clash royale related code you would like to share, we
could incorporate it into this library since its name is very generic,
i.e. it refers to the game as a whole.

Tests
-----

Follow the instructions in ``test/config.yaml``